from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 1 - Planning',
  'Intended Audience :: Education',
  'Operating System :: POSIX :: Linux',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='pycourseexam',
  version='0.0.1',
  description='Módulo para determinar alumnos que aprobaron el curso, dependiendo la secuencia de examenes (parcial, recuperatorio), la cantidad de examenes, y las notas para aprobarlos.',
  long_description_content_type="text/markdown",
  long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
  url='',  
  author='@Mato',
  author_email='no@email.org',
  license='MIT', 
  classifiers=classifiers,
  keywords='student, course management, course, university', 
  packages=find_packages(),
  install_requires=[''] 
)



import pandas as pd
import numpy as np


# In[1960]:


# Esqueleto de la función. Llama a las otras funciones para cada tarea
def approve(data, cond):
    col_name = []
    col_name_total = []

    # Chequeamos columnas y examenes
    status = check(list(data), cond)
    print(status)
    if status == 'error':
        print('Tests and columns do not match')
        return
    
    # Iteramos por el dict de configuración
    for key, value1 in cond.items():
    
        #Si entre los elementos encontramos un dict (que seria los grupos de examenes)
        # Analizamos sus valores
        if type(value1) is dict:
            group_keys = list(value1.keys())
            group_items = [value1[x] for x in group_keys]
            # Se le agrega el _ porque si no hay recuperatorio, queda con el mismo nombre de la col original
            col_name = ' '.join(group_keys) + '_' 
            col_name_total.append(col_name)
            data[col_name] = data.apply(lambda x: calc(x[group_keys], group_items, group_keys), axis =1)

    data['final_mark'] = data.apply(lambda x: final_mark(x[col_name_total]), axis = 1)
    data.drop(col_name_total, inplace=True, axis=1)

    
# Controla que los campos de la configuración estén en la base cargada
def check(columns, cond):
    # Creamos una lista con todas las lleves de último nivel del dict
    keys = set([ name for groups
            in cond.values() for name in groups.keys() ])
    col = set(columns)  
    check =  all(item in col for item in keys)

    if check is True:
        print("The list {} contains all elements of the list {}".format(keys, col))    
        return 'ok'
    else:
        return 'error'
    
# Calcula las notas mas alta para cada instancia, o si está desaprobado, devuelve NULL    
def calc(value, passed, keys):
    value = value.tolist()
    for value,passed,keys in zip(value,passed, keys):
        if value < passed:
            pass
        elif value >= passed:
            return value

# Calcula la situación final del alumno
def final_mark(dataset):
    if (dataset.isna()).any():
        return 'Failed'
    else:
        return dataset.mean()

